==> flink-1.12.7-src.tgz: flink-1.12.7/flink-table/flink-table-planner-blink/src/test/scala/org/apache/flink/table/planner/utils/DateTimeTestUtil.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.utils

import org.apache.flink.table.data.util.DataFormatConverters.{LocalDateConverter, LocalTimeConverter}
import org.apache.flink.table.runtime.functions.SqlDateTimeUtils

import org.apache.calcite.avatica.util.DateTimeUtils
import org.apache.calcite.avatica.util.DateTimeUtils.dateStringToUnixDate

import java.time.{LocalDate, LocalDateTime, LocalTime}

object DateTimeTestUtil {

  def localDate(s: String): LocalDate = {
    if (s == null) {
      null
    } else {
      LocalDateConverter.INSTANCE.toExternal(dateStringToUnixDate(s))
    }
  }

  def localTime(s: String): LocalTime = {
    if (s == null) {
      null
    } else {
      LocalTimeConverter.INSTANCE.toExternal(DateTimeUtils.timeStringToUnixDate(s))
    }
  }

  def localDateTime(s: String): LocalDateTime = {
    if (s == null) {
      null
    } else {
      SqlDateTimeUtils.toTimestampData(s).toLocalDateTime
    }
  }
}

==> flink-1.13.6-src.tgz: flink-1.13.6/flink-table/flink-table-planner-blink/src/test/scala/org/apache/flink/table/planner/utils/DateTimeTestUtil.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.planner.utils

import org.apache.flink.table.data.util.DataFormatConverters.{LocalDateConverter, LocalTimeConverter}
import org.apache.flink.table.runtime.functions.SqlDateTimeUtils

import org.apache.calcite.avatica.util.DateTimeUtils
import org.apache.calcite.avatica.util.DateTimeUtils.dateStringToUnixDate
import java.time.{LocalDate, LocalDateTime, LocalTime, ZoneId}

object DateTimeTestUtil {

  def localDate(s: String): LocalDate = {
    if (s == null) {
      null
    } else {
      LocalDateConverter.INSTANCE.toExternal(dateStringToUnixDate(s))
    }
  }

  def localTime(s: String): LocalTime = {
    if (s == null) {
      null
    } else {
      LocalTimeConverter.INSTANCE.toExternal(DateTimeUtils.timeStringToUnixDate(s))
    }
  }

  def localDateTime(s: String): LocalDateTime = {
    if (s == null) {
      null
    } else {
      SqlDateTimeUtils.toTimestampData(s).toLocalDateTime
    }
  }

  def toEpochMills(s: String, zone: ZoneId): Long = {
    LocalDateTime.parse(s).atZone(zone).toInstant.toEpochMilli
  }
}
